# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.config_stream import ConfigStream
from ..types.create_stream_out import CreateStreamOut
from ..types.get_probe_stream_out import GetProbeStreamOut
from ..types.source_stream import SourceStream
from ..types.target_stream import TargetStream
from .raw_client import AsyncRawDeprecatedStreamingClient, RawDeprecatedStreamingClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class DeprecatedStreamingClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawDeprecatedStreamingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawDeprecatedStreamingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawDeprecatedStreamingClient
        """
        return self._raw_client

    def create_stream(
        self,
        *,
        voices: typing.Sequence[int],
        dictionaries: typing.Sequence[int],
        config: ConfigStream,
        source_stream: SourceStream,
        target_streams: typing.Sequence[TargetStream],
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        initial_delay: typing.Optional[int] = OMIT,
        timeout_in_mins: typing.Optional[int] = OMIT,
        start_time: typing.Optional[dt.datetime] = OMIT,
        end_time: typing.Optional[dt.datetime] = OMIT,
        timezone: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateStreamOut:
        """
        Parameters
        ----------
        voices : typing.Sequence[int]
            List of voice identifiers to be used in the stream.

        dictionaries : typing.Sequence[int]
            List of dictionary identifiers to be used in the stream.

        config : ConfigStream
            The shared configuration for the streaming pipeline.

        source_stream : SourceStream
            The source stream configuration details.

        target_streams : typing.Sequence[TargetStream]
            List of target stream configurations.

        name : typing.Optional[str]
            The name of the stream.

        description : typing.Optional[str]
            The description of the stream.

        initial_delay : typing.Optional[int]
            The initial delay in seconds before starting the stream creation process.

        timeout_in_mins : typing.Optional[int]
            The maximum duration in minutes for the stream creation process before timing out.

        start_time : typing.Optional[dt.datetime]

        end_time : typing.Optional[dt.datetime]

        timezone : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateStreamOut
            Successful Response

        Examples
        --------
        from camb import CambApi, ConfigStream, SourceStream, TargetStream

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.deprecated_streaming.create_stream(
            voices=[1],
            dictionaries=[1],
            config=ConfigStream(),
            source_stream=SourceStream(
                language=1,
                url="url",
            ),
            target_streams=[
                TargetStream(
                    languages=[1],
                    url="url",
                    type=1,
                )
            ],
        )
        """
        _response = self._raw_client.create_stream(
            voices=voices,
            dictionaries=dictionaries,
            config=config,
            source_stream=source_stream,
            target_streams=target_streams,
            name=name,
            description=description,
            initial_delay=initial_delay,
            timeout_in_mins=timeout_in_mins,
            start_time=start_time,
            end_time=end_time,
            timezone=timezone,
            request_options=request_options,
        )
        return _response.data

    def get_stream_result(
        self,
        stream_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, typing.Any]:
        """
        Parameters
        ----------
        stream_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Any]
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.deprecated_streaming.get_stream_result(
            stream_id=1,
        )
        """
        _response = self._raw_client.get_stream_result(stream_id, run_id=run_id, request_options=request_options)
        return _response.data

    def stop_stream(
        self,
        stream_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, typing.Any]:
        """
        Parameters
        ----------
        stream_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Any]
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.deprecated_streaming.stop_stream(
            stream_id=1,
        )
        """
        _response = self._raw_client.stop_stream(stream_id, run_id=run_id, request_options=request_options)
        return _response.data

    def get_probe_stream(
        self,
        *,
        url: str,
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        passphrase: typing.Optional[str] = OMIT,
        stream_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetProbeStreamOut:
        """
        Parameters
        ----------
        url : str

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        passphrase : typing.Optional[str]

        stream_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetProbeStreamOut
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.deprecated_streaming.get_probe_stream(
            url="url",
        )
        """
        _response = self._raw_client.get_probe_stream(
            url=url,
            run_id=run_id,
            traceparent=traceparent,
            passphrase=passphrase,
            stream_id=stream_id,
            request_options=request_options,
        )
        return _response.data


class AsyncDeprecatedStreamingClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawDeprecatedStreamingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawDeprecatedStreamingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawDeprecatedStreamingClient
        """
        return self._raw_client

    async def create_stream(
        self,
        *,
        voices: typing.Sequence[int],
        dictionaries: typing.Sequence[int],
        config: ConfigStream,
        source_stream: SourceStream,
        target_streams: typing.Sequence[TargetStream],
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        initial_delay: typing.Optional[int] = OMIT,
        timeout_in_mins: typing.Optional[int] = OMIT,
        start_time: typing.Optional[dt.datetime] = OMIT,
        end_time: typing.Optional[dt.datetime] = OMIT,
        timezone: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateStreamOut:
        """
        Parameters
        ----------
        voices : typing.Sequence[int]
            List of voice identifiers to be used in the stream.

        dictionaries : typing.Sequence[int]
            List of dictionary identifiers to be used in the stream.

        config : ConfigStream
            The shared configuration for the streaming pipeline.

        source_stream : SourceStream
            The source stream configuration details.

        target_streams : typing.Sequence[TargetStream]
            List of target stream configurations.

        name : typing.Optional[str]
            The name of the stream.

        description : typing.Optional[str]
            The description of the stream.

        initial_delay : typing.Optional[int]
            The initial delay in seconds before starting the stream creation process.

        timeout_in_mins : typing.Optional[int]
            The maximum duration in minutes for the stream creation process before timing out.

        start_time : typing.Optional[dt.datetime]

        end_time : typing.Optional[dt.datetime]

        timezone : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateStreamOut
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi, ConfigStream, SourceStream, TargetStream

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.deprecated_streaming.create_stream(
                voices=[1],
                dictionaries=[1],
                config=ConfigStream(),
                source_stream=SourceStream(
                    language=1,
                    url="url",
                ),
                target_streams=[
                    TargetStream(
                        languages=[1],
                        url="url",
                        type=1,
                    )
                ],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_stream(
            voices=voices,
            dictionaries=dictionaries,
            config=config,
            source_stream=source_stream,
            target_streams=target_streams,
            name=name,
            description=description,
            initial_delay=initial_delay,
            timeout_in_mins=timeout_in_mins,
            start_time=start_time,
            end_time=end_time,
            timezone=timezone,
            request_options=request_options,
        )
        return _response.data

    async def get_stream_result(
        self,
        stream_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, typing.Any]:
        """
        Parameters
        ----------
        stream_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.deprecated_streaming.get_stream_result(
                stream_id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_stream_result(stream_id, run_id=run_id, request_options=request_options)
        return _response.data

    async def stop_stream(
        self,
        stream_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, typing.Any]:
        """
        Parameters
        ----------
        stream_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.deprecated_streaming.stop_stream(
                stream_id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.stop_stream(stream_id, run_id=run_id, request_options=request_options)
        return _response.data

    async def get_probe_stream(
        self,
        *,
        url: str,
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        passphrase: typing.Optional[str] = OMIT,
        stream_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetProbeStreamOut:
        """
        Parameters
        ----------
        url : str

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        passphrase : typing.Optional[str]

        stream_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetProbeStreamOut
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.deprecated_streaming.get_probe_stream(
                url="url",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_probe_stream(
            url=url,
            run_id=run_id,
            traceparent=traceparent,
            passphrase=passphrase,
            stream_id=stream_id,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.create_tts_out import CreateTtsOut
from ..types.gender import Gender
from ..types.languages import Languages
from ..types.orchestrator_pipeline_result import OrchestratorPipelineResult
from ..types.stream_tts_inference_options import StreamTtsInferenceOptions
from ..types.stream_tts_output_configuration import StreamTtsOutputConfiguration
from ..types.stream_tts_voice_settings import StreamTtsVoiceSettings
from .raw_client import AsyncRawTextToSpeechClient, RawTextToSpeechClient
from .types.create_stream_tts_request_payload_language import CreateStreamTtsRequestPayloadLanguage
from .types.create_stream_tts_request_payload_speech_model import CreateStreamTtsRequestPayloadSpeechModel
from .types.get_tts_results_tts_results_post_response_value import GetTtsResultsTtsResultsPostResponseValue
from .types.get_tts_run_info_tts_result_run_id_get_response import GetTtsRunInfoTtsResultRunIdGetResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TextToSpeechClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTextToSpeechClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTextToSpeechClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTextToSpeechClient
        """
        return self._raw_client

    def tts(
        self,
        *,
        text: str,
        language: CreateStreamTtsRequestPayloadLanguage,
        voice_id: int,
        speech_model: typing.Optional[CreateStreamTtsRequestPayloadSpeechModel] = OMIT,
        user_instructions: typing.Optional[str] = OMIT,
        enhance_named_entities_pronunciation: typing.Optional[bool] = OMIT,
        output_configuration: typing.Optional[StreamTtsOutputConfiguration] = OMIT,
        voice_settings: typing.Optional[StreamTtsVoiceSettings] = OMIT,
        inference_options: typing.Optional[StreamTtsInferenceOptions] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Parameters
        ----------
        text : str

        language : CreateStreamTtsRequestPayloadLanguage

        voice_id : int

        speech_model : typing.Optional[CreateStreamTtsRequestPayloadSpeechModel]

        user_instructions : typing.Optional[str]

        enhance_named_entities_pronunciation : typing.Optional[bool]

        output_configuration : typing.Optional[StreamTtsOutputConfiguration]

        voice_settings : typing.Optional[StreamTtsVoiceSettings]

        inference_options : typing.Optional[StreamTtsInferenceOptions]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[bytes]
            Streaming audio response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.text_to_speech.tts(
            text="foo",
            language="ar-kw",
            voice_id=1,
        )
        """
        with self._raw_client.tts(
            text=text,
            language=language,
            voice_id=voice_id,
            speech_model=speech_model,
            user_instructions=user_instructions,
            enhance_named_entities_pronunciation=enhance_named_entities_pronunciation,
            output_configuration=output_configuration,
            voice_settings=voice_settings,
            inference_options=inference_options,
            request_options=request_options,
        ) as r:
            yield from r.data

    def create_tts(
        self,
        *,
        text: str,
        voice_id: int,
        language: Languages,
        run_id: typing.Optional[int] = None,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        gender: typing.Optional[Gender] = OMIT,
        age: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateTtsOut:
        """
        Parameters
        ----------
        text : str

        voice_id : int

        language : Languages

        run_id : typing.Optional[int]

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        gender : typing.Optional[Gender]

        age : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateTtsOut
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.text_to_speech.create_tts(
            text="text",
            voice_id=1,
            language=1,
        )
        """
        _response = self._raw_client.create_tts(
            text=text,
            voice_id=voice_id,
            language=language,
            run_id=run_id,
            project_name=project_name,
            project_description=project_description,
            folder_id=folder_id,
            gender=gender,
            age=age,
            request_options=request_options,
        )
        return _response.data

    def get_tts_result(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineResult:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineResult
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.text_to_speech.get_tts_result(
            task_id="task_id",
        )
        """
        _response = self._raw_client.get_tts_result(task_id, run_id=run_id, request_options=request_options)
        return _response.data

    def get_tts_run_info(
        self,
        run_id: typing.Optional[int],
        *,
        output_type: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetTtsRunInfoTtsResultRunIdGetResponse:
        """
        Retrieves the result of a Text To Speech (TTS) run.

        This endpoint validates the provided `run_id` and fetches the corresponding TTS-generated audio.
        The user must have valid access to the run. The function supports two output formats:
        - `RAW_BYTES`: Streams the audio file directly.
        - `FILE_URL`: Returns a pre-signed URL to download the audio file.

        Args:
            run_id (int): Unique identifier for the TTS run.
            api_key_obj (dict): API key object used for authentication and storage preferences.
            traceparent (Optional[str]): Traceparent header for distributed tracing.
            output_type (OutputType, optional): Determines the output format. Defaults to `RAW_BYTES`.

        Returns:
            StreamingResponse | GetTTSOut:
                - If `output_type = RAW_BYTES`: A streaming response containing the TTS-generated audio in FLAC format.
                - If `output_type = FILE_URL`: A URL pointing to the stored TTS-generated audio file.

        Raises:
            HTTPException:
                - 400 BAD REQUEST if the run ID is invalid or does not belong to a TTS process.
                - 500 INTERNAL SERVER ERROR if fetching or streaming the audio fails.

        Assumptions:
            - The user has valid access to the `run_id`.
            - The `run_id` corresponds to a valid TTS run.
            - There is only **one** dialogue associated with the given `run_id`.

        Parameters
        ----------
        run_id : typing.Optional[int]

        output_type : typing.Optional[str]
            Output format for the Text To Speech result

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetTtsRunInfoTtsResultRunIdGetResponse
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.text_to_speech.get_tts_run_info(
            run_id=1,
        )
        """
        _response = self._raw_client.get_tts_run_info(run_id, output_type=output_type, request_options=request_options)
        return _response.data

    def get_tts_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue]
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.text_to_speech.get_tts_results(
            run_ids=[1],
        )
        """
        _response = self._raw_client.get_tts_results(
            run_ids=run_ids, run_id=run_id, traceparent=traceparent, request_options=request_options
        )
        return _response.data

    def get_tts_result_discord(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineResult:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineResult
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.text_to_speech.get_tts_result_discord(
            task_id="task_id",
        )
        """
        _response = self._raw_client.get_tts_result_discord(task_id, run_id=run_id, request_options=request_options)
        return _response.data


class AsyncTextToSpeechClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTextToSpeechClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTextToSpeechClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTextToSpeechClient
        """
        return self._raw_client

    async def tts(
        self,
        *,
        text: str,
        language: CreateStreamTtsRequestPayloadLanguage,
        voice_id: int,
        speech_model: typing.Optional[CreateStreamTtsRequestPayloadSpeechModel] = OMIT,
        user_instructions: typing.Optional[str] = OMIT,
        enhance_named_entities_pronunciation: typing.Optional[bool] = OMIT,
        output_configuration: typing.Optional[StreamTtsOutputConfiguration] = OMIT,
        voice_settings: typing.Optional[StreamTtsVoiceSettings] = OMIT,
        inference_options: typing.Optional[StreamTtsInferenceOptions] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Parameters
        ----------
        text : str

        language : CreateStreamTtsRequestPayloadLanguage

        voice_id : int

        speech_model : typing.Optional[CreateStreamTtsRequestPayloadSpeechModel]

        user_instructions : typing.Optional[str]

        enhance_named_entities_pronunciation : typing.Optional[bool]

        output_configuration : typing.Optional[StreamTtsOutputConfiguration]

        voice_settings : typing.Optional[StreamTtsVoiceSettings]

        inference_options : typing.Optional[StreamTtsInferenceOptions]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[bytes]
            Streaming audio response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.text_to_speech.tts(
                text="foo",
                language="ar-kw",
                voice_id=1,
            )


        asyncio.run(main())
        """
        async with self._raw_client.tts(
            text=text,
            language=language,
            voice_id=voice_id,
            speech_model=speech_model,
            user_instructions=user_instructions,
            enhance_named_entities_pronunciation=enhance_named_entities_pronunciation,
            output_configuration=output_configuration,
            voice_settings=voice_settings,
            inference_options=inference_options,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk

    async def create_tts(
        self,
        *,
        text: str,
        voice_id: int,
        language: Languages,
        run_id: typing.Optional[int] = None,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        gender: typing.Optional[Gender] = OMIT,
        age: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateTtsOut:
        """
        Parameters
        ----------
        text : str

        voice_id : int

        language : Languages

        run_id : typing.Optional[int]

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        gender : typing.Optional[Gender]

        age : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateTtsOut
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.text_to_speech.create_tts(
                text="text",
                voice_id=1,
                language=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_tts(
            text=text,
            voice_id=voice_id,
            language=language,
            run_id=run_id,
            project_name=project_name,
            project_description=project_description,
            folder_id=folder_id,
            gender=gender,
            age=age,
            request_options=request_options,
        )
        return _response.data

    async def get_tts_result(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineResult:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineResult
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.text_to_speech.get_tts_result(
                task_id="task_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_tts_result(task_id, run_id=run_id, request_options=request_options)
        return _response.data

    async def get_tts_run_info(
        self,
        run_id: typing.Optional[int],
        *,
        output_type: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetTtsRunInfoTtsResultRunIdGetResponse:
        """
        Retrieves the result of a Text To Speech (TTS) run.

        This endpoint validates the provided `run_id` and fetches the corresponding TTS-generated audio.
        The user must have valid access to the run. The function supports two output formats:
        - `RAW_BYTES`: Streams the audio file directly.
        - `FILE_URL`: Returns a pre-signed URL to download the audio file.

        Args:
            run_id (int): Unique identifier for the TTS run.
            api_key_obj (dict): API key object used for authentication and storage preferences.
            traceparent (Optional[str]): Traceparent header for distributed tracing.
            output_type (OutputType, optional): Determines the output format. Defaults to `RAW_BYTES`.

        Returns:
            StreamingResponse | GetTTSOut:
                - If `output_type = RAW_BYTES`: A streaming response containing the TTS-generated audio in FLAC format.
                - If `output_type = FILE_URL`: A URL pointing to the stored TTS-generated audio file.

        Raises:
            HTTPException:
                - 400 BAD REQUEST if the run ID is invalid or does not belong to a TTS process.
                - 500 INTERNAL SERVER ERROR if fetching or streaming the audio fails.

        Assumptions:
            - The user has valid access to the `run_id`.
            - The `run_id` corresponds to a valid TTS run.
            - There is only **one** dialogue associated with the given `run_id`.

        Parameters
        ----------
        run_id : typing.Optional[int]

        output_type : typing.Optional[str]
            Output format for the Text To Speech result

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetTtsRunInfoTtsResultRunIdGetResponse
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.text_to_speech.get_tts_run_info(
                run_id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_tts_run_info(
            run_id, output_type=output_type, request_options=request_options
        )
        return _response.data

    async def get_tts_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue]
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.text_to_speech.get_tts_results(
                run_ids=[1],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_tts_results(
            run_ids=run_ids, run_id=run_id, traceparent=traceparent, request_options=request_options
        )
        return _response.data

    async def get_tts_result_discord(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineResult:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineResult
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.text_to_speech.get_tts_result_discord(
                task_id="task_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_tts_result_discord(
            task_id, run_id=run_id, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.get_audio_separation_result_out import GetAudioSeparationResultOut
from ..types.http_validation_error import HttpValidationError
from ..types.orchestrator_pipeline_call_result import OrchestratorPipelineCallResult
from ..types.orchestrator_pipeline_result import OrchestratorPipelineResult

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawAudioSeparationClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_audio_separation(
        self,
        *,
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        media_file: typing.Optional[core.File] = OMIT,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[OrchestratorPipelineCallResult]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        media_file : typing.Optional[core.File]
            See core.File for more documentation

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrchestratorPipelineCallResult]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "audio-separation",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "project_name": project_name,
                "project_description": project_description,
                "folder_id": folder_id,
            },
            files={
                **({"media_file": media_file} if media_file is not None else {}),
            },
            headers={
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineCallResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineCallResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_audio_separation_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"audio-separation/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_audio_separation_run_info(
        self, run_id: typing.Optional[int], *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[GetAudioSeparationResultOut]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetAudioSeparationResultOut]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"audio-separation-result/{jsonable_encoder(run_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetAudioSeparationResultOut,
                    parse_obj_as(
                        type_=GetAudioSeparationResultOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_audio_separation_runs_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Dict[str, GetAudioSeparationResultOut]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Dict[str, GetAudioSeparationResultOut]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "audio-separation-results",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "run_ids": run_ids,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, GetAudioSeparationResultOut],
                    parse_obj_as(
                        type_=typing.Dict[str, GetAudioSeparationResultOut],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawAudioSeparationClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_audio_separation(
        self,
        *,
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        media_file: typing.Optional[core.File] = OMIT,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[OrchestratorPipelineCallResult]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        media_file : typing.Optional[core.File]
            See core.File for more documentation

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrchestratorPipelineCallResult]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "audio-separation",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "project_name": project_name,
                "project_description": project_description,
                "folder_id": folder_id,
            },
            files={
                **({"media_file": media_file} if media_file is not None else {}),
            },
            headers={
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineCallResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineCallResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_audio_separation_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"audio-separation/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_audio_separation_run_info(
        self, run_id: typing.Optional[int], *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[GetAudioSeparationResultOut]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetAudioSeparationResultOut]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"audio-separation-result/{jsonable_encoder(run_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetAudioSeparationResultOut,
                    parse_obj_as(
                        type_=GetAudioSeparationResultOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_audio_separation_runs_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Dict[str, GetAudioSeparationResultOut]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Dict[str, GetAudioSeparationResultOut]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "audio-separation-results",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "run_ids": run_ids,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, GetAudioSeparationResultOut],
                    parse_obj_as(
                        type_=typing.Dict[str, GetAudioSeparationResultOut],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

from .. import core
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.languages import Languages
from ..types.orchestrator_pipeline_call_result import OrchestratorPipelineCallResult
from ..types.orchestrator_pipeline_result import OrchestratorPipelineResult
from ..types.transcription_result import TranscriptionResult
from .raw_client import AsyncRawTranscriptionClient, RawTranscriptionClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TranscriptionClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTranscriptionClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTranscriptionClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTranscriptionClient
        """
        return self._raw_client

    def create_transcription(
        self,
        *,
        language: Languages,
        run_id: typing.Optional[int] = None,
        media_file: typing.Optional[core.File] = OMIT,
        media_url: typing.Optional[str] = OMIT,
        file: typing.Optional[core.File] = OMIT,
        audio_url: typing.Optional[str] = OMIT,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineCallResult:
        """
        Parameters
        ----------
        language : Languages
            Signed URL to audio file for transcription

        run_id : typing.Optional[int]

        media_file : typing.Optional[core.File]
            See core.File for more documentation

        media_url : typing.Optional[str]
            Signed URL to media file for transcription

        file : typing.Optional[core.File]
            See core.File for more documentation

        audio_url : typing.Optional[str]
            [DEPRECATED] Use 'audio_url' instead

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineCallResult
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.transcription.create_transcription(
            language=1,
        )
        """
        _response = self._raw_client.create_transcription(
            language=language,
            run_id=run_id,
            media_file=media_file,
            media_url=media_url,
            file=file,
            audio_url=audio_url,
            project_name=project_name,
            project_description=project_description,
            folder_id=folder_id,
            request_options=request_options,
        )
        return _response.data

    def get_transcription_task_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineResult:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineResult
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.transcription.get_transcription_task_status(
            task_id="task_id",
        )
        """
        _response = self._raw_client.get_transcription_task_status(
            task_id, run_id=run_id, request_options=request_options
        )
        return _response.data

    def get_transcription_result(
        self,
        run_id: typing.Optional[int],
        *,
        word_level_timestamps: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TranscriptionResult:
        """
        NOTE: This endpoint should be called only by the users to get values for their runs via API.
        Further we need to validate if the user has access to the run_id, otherwise we should not return the output urls.

        Parameters
        ----------
        run_id : typing.Optional[int]

        word_level_timestamps : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TranscriptionResult
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.transcription.get_transcription_result(
            run_id=1,
        )
        """
        _response = self._raw_client.get_transcription_result(
            run_id, word_level_timestamps=word_level_timestamps, request_options=request_options
        )
        return _response.data

    def get_transcription_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, TranscriptionResult]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, TranscriptionResult]
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.transcription.get_transcription_results(
            run_ids=[1],
        )
        """
        _response = self._raw_client.get_transcription_results(
            run_ids=run_ids, run_id=run_id, traceparent=traceparent, request_options=request_options
        )
        return _response.data


class AsyncTranscriptionClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTranscriptionClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTranscriptionClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTranscriptionClient
        """
        return self._raw_client

    async def create_transcription(
        self,
        *,
        language: Languages,
        run_id: typing.Optional[int] = None,
        media_file: typing.Optional[core.File] = OMIT,
        media_url: typing.Optional[str] = OMIT,
        file: typing.Optional[core.File] = OMIT,
        audio_url: typing.Optional[str] = OMIT,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineCallResult:
        """
        Parameters
        ----------
        language : Languages
            Signed URL to audio file for transcription

        run_id : typing.Optional[int]

        media_file : typing.Optional[core.File]
            See core.File for more documentation

        media_url : typing.Optional[str]
            Signed URL to media file for transcription

        file : typing.Optional[core.File]
            See core.File for more documentation

        audio_url : typing.Optional[str]
            [DEPRECATED] Use 'audio_url' instead

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineCallResult
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transcription.create_transcription(
                language=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_transcription(
            language=language,
            run_id=run_id,
            media_file=media_file,
            media_url=media_url,
            file=file,
            audio_url=audio_url,
            project_name=project_name,
            project_description=project_description,
            folder_id=folder_id,
            request_options=request_options,
        )
        return _response.data

    async def get_transcription_task_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineResult:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineResult
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transcription.get_transcription_task_status(
                task_id="task_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_transcription_task_status(
            task_id, run_id=run_id, request_options=request_options
        )
        return _response.data

    async def get_transcription_result(
        self,
        run_id: typing.Optional[int],
        *,
        word_level_timestamps: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TranscriptionResult:
        """
        NOTE: This endpoint should be called only by the users to get values for their runs via API.
        Further we need to validate if the user has access to the run_id, otherwise we should not return the output urls.

        Parameters
        ----------
        run_id : typing.Optional[int]

        word_level_timestamps : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TranscriptionResult
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transcription.get_transcription_result(
                run_id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_transcription_result(
            run_id, word_level_timestamps=word_level_timestamps, request_options=request_options
        )
        return _response.data

    async def get_transcription_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, TranscriptionResult]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, TranscriptionResult]
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.transcription.get_transcription_results(
                run_ids=[1],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_transcription_results(
            run_ids=run_ids, run_id=run_id, traceparent=traceparent, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .languages import Languages
from .stream_type import StreamType


class TargetStream(UniversalBaseModel):
    languages: typing.List[Languages]
    url: str
    type: StreamType
    passphrase: typing.Optional[str] = None
    streamid: typing.Optional[str] = None
    pids: typing.Optional[typing.List[typing.Optional[int]]] = None
    transcode_video: typing.Optional[bool] = None
    embed_subtitles: typing.Optional[bool] = None
    audio_codec: typing.Optional[str] = None
    audio_bitrate: typing.Optional[str] = None
    audio_channel_layout: typing.Optional[str] = None
    latency: typing.Optional[int] = None
    constant_bitrate: typing.Optional[bool] = None
    relay_output: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .languages import Languages


class ProjectDetails(UniversalBaseModel):
    project_name: str
    project_description: typing.Optional[str] = None
    created_at: dt.datetime
    source_language: Languages
    target_languages: typing.List[Languages]
    duration: typing.Optional[float] = None
    folder_id: typing.Optional[int] = None
    studio_url: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.dictionary_with_terms import DictionaryWithTerms
from ..types.http_validation_error import HttpValidationError
from ..types.term_translation_input import TermTranslationInput

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawDictionariesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_dictionaries(
        self, *, run_id: typing.Optional[int] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[typing.List[DictionaryWithTerms]]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.List[DictionaryWithTerms]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "dictionaries",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[DictionaryWithTerms],
                    parse_obj_as(
                        type_=typing.List[DictionaryWithTerms],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create_dictionary_from_file(
        self,
        *,
        dictionary_file: core.File,
        dictionary_name: str,
        run_id: typing.Optional[int] = None,
        dictionary_description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Any]:
        """
        Parameters
        ----------
        dictionary_file : core.File
            See core.File for more documentation

        dictionary_name : str
            The name of the dictonary to be created. This is mainly used for organizational purposes.

        run_id : typing.Optional[int]

        dictionary_description : typing.Optional[str]
            The description of the dictionary to be created. This is an optional field that is used to help you provide some info about your dictionaries for better organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Any]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "dictionaries/create-from-file",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "dictionary_name": dictionary_name,
                "dictionary_description": dictionary_description,
            },
            files={
                "dictionary_file": dictionary_file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if _response is None or not _response.text.strip():
                return HttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_dictionary_info(
        self,
        dictionary_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[DictionaryWithTerms]:
        """
        Parameters
        ----------
        dictionary_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DictionaryWithTerms]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"dictionaries/{jsonable_encoder(dictionary_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DictionaryWithTerms,
                    parse_obj_as(
                        type_=DictionaryWithTerms,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete_dictionary(
        self,
        dictionary_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Any]:
        """
        Parameters
        ----------
        dictionary_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Any]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"dictionaries/{jsonable_encoder(dictionary_id)}",
            method="DELETE",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return HttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_dictionary_details(
        self,
        dictionary_id: int,
        *,
        limit: typing.Optional[int] = None,
        search_term: typing.Optional[str] = None,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[DictionaryWithTerms]:
        """
        Parameters
        ----------
        dictionary_id : int

        limit : typing.Optional[int]
            Limit how many terms are returned when fetching the dictionary details.

        search_term : typing.Optional[str]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DictionaryWithTerms]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"dictionaries/{jsonable_encoder(dictionary_id)}/full-details",
            method="GET",
            params={
                "limit": limit,
                "search_term": search_term,
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DictionaryWithTerms,
                    parse_obj_as(
                        type_=DictionaryWithTerms,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def add_term_to_dictionary(
        self,
        dictionary_id: int,
        *,
        translations: typing.Sequence[TermTranslationInput],
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Any]:
        """
        Parameters
        ----------
        dictionary_id : int

        translations : typing.Sequence[TermTranslationInput]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Any]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"dictionaries/{jsonable_encoder(dictionary_id)}/add-term",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "translations": convert_and_respect_annotation_metadata(
                    object_=translations, annotation=typing.Sequence[TermTranslationInput], direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if _response is None or not _response.text.strip():
                return HttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update_term_translation_in_dictionary_using_term_id(
        self,
        dictionary_id: int,
        term_id: int,
        *,
        translations: typing.Sequence[TermTranslationInput],
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Any]:
        """
        Parameters
        ----------
        dictionary_id : int

        term_id : int

        translations : typing.Sequence[TermTranslationInput]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Any]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"dictionaries/term/{jsonable_encoder(dictionary_id)}/{jsonable_encoder(term_id)}",
            method="PUT",
            params={
                "run_id": run_id,
            },
            json={
                "translations": convert_and_respect_annotation_metadata(
                    object_=translations, annotation=typing.Sequence[TermTranslationInput], direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if _response is None or not _response.text.strip():
                return HttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete_dictionary_term(
        self,
        dictionary_id: int,
        term_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Any]:
        """
        Parameters
        ----------
        dictionary_id : int

        term_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Any]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"dictionaries/term/{jsonable_encoder(dictionary_id)}/{jsonable_encoder(term_id)}",
            method="DELETE",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return HttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawDictionariesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_dictionaries(
        self, *, run_id: typing.Optional[int] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[typing.List[DictionaryWithTerms]]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.List[DictionaryWithTerms]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "dictionaries",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[DictionaryWithTerms],
                    parse_obj_as(
                        type_=typing.List[DictionaryWithTerms],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create_dictionary_from_file(
        self,
        *,
        dictionary_file: core.File,
        dictionary_name: str,
        run_id: typing.Optional[int] = None,
        dictionary_description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Any]:
        """
        Parameters
        ----------
        dictionary_file : core.File
            See core.File for more documentation

        dictionary_name : str
            The name of the dictonary to be created. This is mainly used for organizational purposes.

        run_id : typing.Optional[int]

        dictionary_description : typing.Optional[str]
            The description of the dictionary to be created. This is an optional field that is used to help you provide some info about your dictionaries for better organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Any]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "dictionaries/create-from-file",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "dictionary_name": dictionary_name,
                "dictionary_description": dictionary_description,
            },
            files={
                "dictionary_file": dictionary_file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if _response is None or not _response.text.strip():
                return AsyncHttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_dictionary_info(
        self,
        dictionary_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[DictionaryWithTerms]:
        """
        Parameters
        ----------
        dictionary_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DictionaryWithTerms]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"dictionaries/{jsonable_encoder(dictionary_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DictionaryWithTerms,
                    parse_obj_as(
                        type_=DictionaryWithTerms,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete_dictionary(
        self,
        dictionary_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Any]:
        """
        Parameters
        ----------
        dictionary_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Any]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"dictionaries/{jsonable_encoder(dictionary_id)}",
            method="DELETE",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return AsyncHttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_dictionary_details(
        self,
        dictionary_id: int,
        *,
        limit: typing.Optional[int] = None,
        search_term: typing.Optional[str] = None,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[DictionaryWithTerms]:
        """
        Parameters
        ----------
        dictionary_id : int

        limit : typing.Optional[int]
            Limit how many terms are returned when fetching the dictionary details.

        search_term : typing.Optional[str]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DictionaryWithTerms]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"dictionaries/{jsonable_encoder(dictionary_id)}/full-details",
            method="GET",
            params={
                "limit": limit,
                "search_term": search_term,
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DictionaryWithTerms,
                    parse_obj_as(
                        type_=DictionaryWithTerms,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def add_term_to_dictionary(
        self,
        dictionary_id: int,
        *,
        translations: typing.Sequence[TermTranslationInput],
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Any]:
        """
        Parameters
        ----------
        dictionary_id : int

        translations : typing.Sequence[TermTranslationInput]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Any]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"dictionaries/{jsonable_encoder(dictionary_id)}/add-term",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "translations": convert_and_respect_annotation_metadata(
                    object_=translations, annotation=typing.Sequence[TermTranslationInput], direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if _response is None or not _response.text.strip():
                return AsyncHttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update_term_translation_in_dictionary_using_term_id(
        self,
        dictionary_id: int,
        term_id: int,
        *,
        translations: typing.Sequence[TermTranslationInput],
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Any]:
        """
        Parameters
        ----------
        dictionary_id : int

        term_id : int

        translations : typing.Sequence[TermTranslationInput]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Any]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"dictionaries/term/{jsonable_encoder(dictionary_id)}/{jsonable_encoder(term_id)}",
            method="PUT",
            params={
                "run_id": run_id,
            },
            json={
                "translations": convert_and_respect_annotation_metadata(
                    object_=translations, annotation=typing.Sequence[TermTranslationInput], direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if _response is None or not _response.text.strip():
                return AsyncHttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete_dictionary_term(
        self,
        dictionary_id: int,
        term_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Any]:
        """
        Parameters
        ----------
        dictionary_id : int

        term_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Any]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"dictionaries/term/{jsonable_encoder(dictionary_id)}/{jsonable_encoder(term_id)}",
            method="DELETE",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return AsyncHttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

ExceptionReasons = typing.Union[
    typing.Literal[
        "HARMFUL_CONTENT_DETECTED",
        "VOICE_CONVERSION_ERROR",
        "PROCESSING_ERROR",
        "SOURCE_TOO_LONG",
        "SOURCE_TOO_LARGE",
        "SOURCE_TYPE_NOT_SUPPORTED",
        "ERROR_DOWNLOADING_SOURCE",
        "TOO_MANY_GDRIVE_REQUESTS",
        "SOURCE_BLOCKED_IN_REGION",
        "SOURCE_IS_AGE_RESTRICTED",
        "SOURCE_NOT_FOUND",
        "MISMATCHED_SOURCE_CODEC",
        "CONTENT_DOES_NOT_MATCH_EXTENSION",
        "INVALID_SOURCE_DATA",
        "VIDEO_DOES_NOT_HAVE_AUDIO_STREAMS",
        "MASTERING_OUT_OF_RANGE",
        "INVALID_AUDIO_TRACKS_SELECTION",
        "PAYMENT_REQUIRED",
        "FORBIDDEN",
        "INTERNAL_ERROR",
        "NONE",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .config_stream import ConfigStream
from .source_stream import SourceStream
from .target_stream import TargetStream


class CreateStreamRequestPayload(UniversalBaseModel):
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the stream.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    The description of the stream.
    """

    initial_delay: typing.Optional[int] = pydantic.Field(default=None)
    """
    The initial delay in seconds before starting the stream creation process.
    """

    timeout_in_mins: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum duration in minutes for the stream creation process before timing out.
    """

    voices: typing.List[int] = pydantic.Field()
    """
    List of voice identifiers to be used in the stream.
    """

    dictionaries: typing.List[int] = pydantic.Field()
    """
    List of dictionary identifiers to be used in the stream.
    """

    config: ConfigStream = pydantic.Field()
    """
    The shared configuration for the streaming pipeline.
    """

    source_stream: SourceStream = pydantic.Field()
    """
    The source stream configuration details.
    """

    target_streams: typing.List[TargetStream] = pydantic.Field()
    """
    List of target stream configurations.
    """

    start_time: typing.Optional[dt.datetime] = None
    end_time: typing.Optional[dt.datetime] = None
    timezone: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class StreamTtsInferenceOptions(UniversalBaseModel):
    """
    Advanced options for controlling the TTS inference process.

    These options are only supported for the MARS-8 family of speech models.

    Attributes:
        stability: A value between 0.0 and 1.0 that controls the stability of
            the output audio.
        temperature: A value between 0.01 and 4.0 that controls the randomness
            of the output. Higher values mean more randomness.
        inference_steps: The number of steps for the diffusion model. A value
            between 1 and 1000.
        speaker_similarity: A value between 0.0 and 1.0 that controls how
            similar the output should be to the reference speaker.
    """

    stability: typing.Optional[float] = None
    temperature: typing.Optional[float] = None
    inference_steps: typing.Optional[int] = None
    speaker_similarity: typing.Optional[float] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.dubbing_result import DubbingResult

GetDubbingRunsResultsDubbingResultsPostResponseValue = typing.Union[DubbingResult, typing.Dict[str, DubbingResult]]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.create_translated_tts_out import CreateTranslatedTtsOut
from ..types.formalities import Formalities
from ..types.gender import Gender
from ..types.languages import Languages
from ..types.orchestrator_pipeline_result import OrchestratorPipelineResult
from .raw_client import AsyncRawTranslatedTtsClient, RawTranslatedTtsClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TranslatedTtsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTranslatedTtsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTranslatedTtsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTranslatedTtsClient
        """
        return self._raw_client

    def create_translated_tts(
        self,
        *,
        text: str,
        voice_id: int,
        source_language: Languages,
        target_language: Languages,
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        age: typing.Optional[int] = OMIT,
        formality: typing.Optional[Formalities] = OMIT,
        gender: typing.Optional[Gender] = OMIT,
        chosen_dictionaries: typing.Optional[typing.Sequence[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateTranslatedTtsOut:
        """
        Parameters
        ----------
        text : str

        voice_id : int

        source_language : Languages

        target_language : Languages

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        age : typing.Optional[int]

        formality : typing.Optional[Formalities]

        gender : typing.Optional[Gender]

        chosen_dictionaries : typing.Optional[typing.Sequence[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateTranslatedTtsOut
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.translated_tts.create_translated_tts(
            text="text",
            voice_id=1,
            source_language=1,
            target_language=1,
        )
        """
        _response = self._raw_client.create_translated_tts(
            text=text,
            voice_id=voice_id,
            source_language=source_language,
            target_language=target_language,
            run_id=run_id,
            traceparent=traceparent,
            project_name=project_name,
            project_description=project_description,
            folder_id=folder_id,
            age=age,
            formality=formality,
            gender=gender,
            chosen_dictionaries=chosen_dictionaries,
            request_options=request_options,
        )
        return _response.data

    def get_translated_tts_task_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineResult:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineResult
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.translated_tts.get_translated_tts_task_status(
            task_id="task_id",
        )
        """
        _response = self._raw_client.get_translated_tts_task_status(
            task_id, run_id=run_id, request_options=request_options
        )
        return _response.data


class AsyncTranslatedTtsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTranslatedTtsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTranslatedTtsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTranslatedTtsClient
        """
        return self._raw_client

    async def create_translated_tts(
        self,
        *,
        text: str,
        voice_id: int,
        source_language: Languages,
        target_language: Languages,
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        age: typing.Optional[int] = OMIT,
        formality: typing.Optional[Formalities] = OMIT,
        gender: typing.Optional[Gender] = OMIT,
        chosen_dictionaries: typing.Optional[typing.Sequence[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateTranslatedTtsOut:
        """
        Parameters
        ----------
        text : str

        voice_id : int

        source_language : Languages

        target_language : Languages

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        age : typing.Optional[int]

        formality : typing.Optional[Formalities]

        gender : typing.Optional[Gender]

        chosen_dictionaries : typing.Optional[typing.Sequence[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateTranslatedTtsOut
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.translated_tts.create_translated_tts(
                text="text",
                voice_id=1,
                source_language=1,
                target_language=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_translated_tts(
            text=text,
            voice_id=voice_id,
            source_language=source_language,
            target_language=target_language,
            run_id=run_id,
            traceparent=traceparent,
            project_name=project_name,
            project_description=project_description,
            folder_id=folder_id,
            age=age,
            formality=formality,
            gender=gender,
            chosen_dictionaries=chosen_dictionaries,
            request_options=request_options,
        )
        return _response.data

    async def get_translated_tts_task_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineResult:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineResult
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.translated_tts.get_translated_tts_task_status(
                task_id="task_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_translated_tts_task_status(
            task_id, run_id=run_id, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from .exception_reasons import ExceptionReasons

OrchestratorPipelineResultExceptionReason = typing.Union[str, ExceptionReasons]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.formalities import Formalities
from ..types.gender import Gender
from ..types.http_validation_error import HttpValidationError
from ..types.languages import Languages
from ..types.orchestrator_pipeline_result import OrchestratorPipelineResult
from ..types.translation_result import TranslationResult

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawTranslationClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def translation_stream(
        self,
        *,
        source_language: Languages,
        target_language: Languages,
        text: str,
        traceparent: typing.Optional[str] = None,
        formality: typing.Optional[Formalities] = OMIT,
        gender: typing.Optional[Gender] = OMIT,
        team_id: typing.Optional[int] = OMIT,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Any]:
        """
        Parameters
        ----------
        source_language : Languages

        target_language : Languages

        text : str

        traceparent : typing.Optional[str]

        formality : typing.Optional[Formalities]

        gender : typing.Optional[Gender]

        team_id : typing.Optional[int]

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Any]
            Text translation stream
        """
        _response = self._client_wrapper.httpx_client.request(
            "translation/stream",
            method="POST",
            json={
                "source_language": source_language,
                "target_language": target_language,
                "text": text,
                "formality": formality,
                "gender": gender,
                "team_id": team_id,
                "project_name": project_name,
                "project_description": project_description,
                "folder_id": folder_id,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if _response is None or not _response.text.strip():
                return HttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create_translation(
        self,
        *,
        texts: typing.Sequence[str],
        source_language: Languages,
        target_language: Languages,
        run_id: typing.Optional[int] = None,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        age: typing.Optional[int] = OMIT,
        formality: typing.Optional[Formalities] = OMIT,
        gender: typing.Optional[Gender] = OMIT,
        chosen_dictionaries: typing.Optional[typing.Sequence[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Any]:
        """
        Parameters
        ----------
        texts : typing.Sequence[str]

        source_language : Languages

        target_language : Languages

        run_id : typing.Optional[int]

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        age : typing.Optional[int]

        formality : typing.Optional[Formalities]

        gender : typing.Optional[Gender]

        chosen_dictionaries : typing.Optional[typing.Sequence[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Any]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "translate",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "project_name": project_name,
                "project_description": project_description,
                "folder_id": folder_id,
                "texts": texts,
                "age": age,
                "formality": formality,
                "gender": gender,
                "source_language": source_language,
                "target_language": target_language,
                "chosen_dictionaries": chosen_dictionaries,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if _response is None or not _response.text.strip():
                return HttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_translation_task_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"translate/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_translation_result(
        self,
        run_id: typing.Optional[int],
        *,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[TranslationResult]:
        """
        NOTE: This endpoint should be called only by the users to get values for their runs via API.
        Further we need to validate if the user has access to the run_id, otherwise we should not return the output urls.

        Parameters
        ----------
        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[TranslationResult]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"translation-result/{jsonable_encoder(run_id)}",
            method="GET",
            headers={
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    TranslationResult,
                    parse_obj_as(
                        type_=TranslationResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_translation_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Dict[str, TranslationResult]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Dict[str, TranslationResult]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "translation-results",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "run_ids": run_ids,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, TranslationResult],
                    parse_obj_as(
                        type_=typing.Dict[str, TranslationResult],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawTranslationClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def translation_stream(
        self,
        *,
        source_language: Languages,
        target_language: Languages,
        text: str,
        traceparent: typing.Optional[str] = None,
        formality: typing.Optional[Formalities] = OMIT,
        gender: typing.Optional[Gender] = OMIT,
        team_id: typing.Optional[int] = OMIT,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Any]:
        """
        Parameters
        ----------
        source_language : Languages

        target_language : Languages

        text : str

        traceparent : typing.Optional[str]

        formality : typing.Optional[Formalities]

        gender : typing.Optional[Gender]

        team_id : typing.Optional[int]

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Any]
            Text translation stream
        """
        _response = await self._client_wrapper.httpx_client.request(
            "translation/stream",
            method="POST",
            json={
                "source_language": source_language,
                "target_language": target_language,
                "text": text,
                "formality": formality,
                "gender": gender,
                "team_id": team_id,
                "project_name": project_name,
                "project_description": project_description,
                "folder_id": folder_id,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if _response is None or not _response.text.strip():
                return AsyncHttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create_translation(
        self,
        *,
        texts: typing.Sequence[str],
        source_language: Languages,
        target_language: Languages,
        run_id: typing.Optional[int] = None,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        age: typing.Optional[int] = OMIT,
        formality: typing.Optional[Formalities] = OMIT,
        gender: typing.Optional[Gender] = OMIT,
        chosen_dictionaries: typing.Optional[typing.Sequence[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Any]:
        """
        Parameters
        ----------
        texts : typing.Sequence[str]

        source_language : Languages

        target_language : Languages

        run_id : typing.Optional[int]

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        age : typing.Optional[int]

        formality : typing.Optional[Formalities]

        gender : typing.Optional[Gender]

        chosen_dictionaries : typing.Optional[typing.Sequence[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Any]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "translate",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "project_name": project_name,
                "project_description": project_description,
                "folder_id": folder_id,
                "texts": texts,
                "age": age,
                "formality": formality,
                "gender": gender,
                "source_language": source_language,
                "target_language": target_language,
                "chosen_dictionaries": chosen_dictionaries,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if _response is None or not _response.text.strip():
                return AsyncHttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_translation_task_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"translate/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_translation_result(
        self,
        run_id: typing.Optional[int],
        *,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[TranslationResult]:
        """
        NOTE: This endpoint should be called only by the users to get values for their runs via API.
        Further we need to validate if the user has access to the run_id, otherwise we should not return the output urls.

        Parameters
        ----------
        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[TranslationResult]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"translation-result/{jsonable_encoder(run_id)}",
            method="GET",
            headers={
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    TranslationResult,
                    parse_obj_as(
                        type_=TranslationResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_translation_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Dict[str, TranslationResult]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Dict[str, TranslationResult]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "translation-results",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "run_ids": run_ids,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, TranslationResult],
                    parse_obj_as(
                        type_=typing.Dict[str, TranslationResult],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.get_setup_story_result_response import GetSetupStoryResultResponse
from ...types.orchestrator_pipeline_call_result import OrchestratorPipelineCallResult

CreateStoryStoryPostResponse = typing.Union[OrchestratorPipelineCallResult, GetSetupStoryResultResponse]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.config_stream import ConfigStream
from ..types.create_stream_out import CreateStreamOut
from ..types.get_probe_stream_out import GetProbeStreamOut
from ..types.http_validation_error import HttpValidationError
from ..types.source_stream import SourceStream
from ..types.target_stream import TargetStream

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawDeprecatedStreamingClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_stream(
        self,
        *,
        voices: typing.Sequence[int],
        dictionaries: typing.Sequence[int],
        config: ConfigStream,
        source_stream: SourceStream,
        target_streams: typing.Sequence[TargetStream],
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        initial_delay: typing.Optional[int] = OMIT,
        timeout_in_mins: typing.Optional[int] = OMIT,
        start_time: typing.Optional[dt.datetime] = OMIT,
        end_time: typing.Optional[dt.datetime] = OMIT,
        timezone: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CreateStreamOut]:
        """
        Parameters
        ----------
        voices : typing.Sequence[int]
            List of voice identifiers to be used in the stream.

        dictionaries : typing.Sequence[int]
            List of dictionary identifiers to be used in the stream.

        config : ConfigStream
            The shared configuration for the streaming pipeline.

        source_stream : SourceStream
            The source stream configuration details.

        target_streams : typing.Sequence[TargetStream]
            List of target stream configurations.

        name : typing.Optional[str]
            The name of the stream.

        description : typing.Optional[str]
            The description of the stream.

        initial_delay : typing.Optional[int]
            The initial delay in seconds before starting the stream creation process.

        timeout_in_mins : typing.Optional[int]
            The maximum duration in minutes for the stream creation process before timing out.

        start_time : typing.Optional[dt.datetime]

        end_time : typing.Optional[dt.datetime]

        timezone : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CreateStreamOut]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/stream",
            method="POST",
            json={
                "name": name,
                "description": description,
                "initial_delay": initial_delay,
                "timeout_in_mins": timeout_in_mins,
                "voices": voices,
                "dictionaries": dictionaries,
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ConfigStream, direction="write"
                ),
                "source_stream": convert_and_respect_annotation_metadata(
                    object_=source_stream, annotation=SourceStream, direction="write"
                ),
                "target_streams": convert_and_respect_annotation_metadata(
                    object_=target_streams, annotation=typing.Sequence[TargetStream], direction="write"
                ),
                "start_time": start_time,
                "end_time": end_time,
                "timezone": timezone,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateStreamOut,
                    parse_obj_as(
                        type_=CreateStreamOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_stream_result(
        self,
        stream_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        stream_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Dict[str, typing.Any]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/stream/{jsonable_encoder(stream_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def stop_stream(
        self,
        stream_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        stream_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Dict[str, typing.Any]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/stream/{jsonable_encoder(stream_id)}/stop",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_probe_stream(
        self,
        *,
        url: str,
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        passphrase: typing.Optional[str] = OMIT,
        stream_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[GetProbeStreamOut]:
        """
        Parameters
        ----------
        url : str

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        passphrase : typing.Optional[str]

        stream_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetProbeStreamOut]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/stream/probe",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "url": url,
                "passphrase": passphrase,
                "stream_id": stream_id,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetProbeStreamOut,
                    parse_obj_as(
                        type_=GetProbeStreamOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawDeprecatedStreamingClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_stream(
        self,
        *,
        voices: typing.Sequence[int],
        dictionaries: typing.Sequence[int],
        config: ConfigStream,
        source_stream: SourceStream,
        target_streams: typing.Sequence[TargetStream],
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        initial_delay: typing.Optional[int] = OMIT,
        timeout_in_mins: typing.Optional[int] = OMIT,
        start_time: typing.Optional[dt.datetime] = OMIT,
        end_time: typing.Optional[dt.datetime] = OMIT,
        timezone: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CreateStreamOut]:
        """
        Parameters
        ----------
        voices : typing.Sequence[int]
            List of voice identifiers to be used in the stream.

        dictionaries : typing.Sequence[int]
            List of dictionary identifiers to be used in the stream.

        config : ConfigStream
            The shared configuration for the streaming pipeline.

        source_stream : SourceStream
            The source stream configuration details.

        target_streams : typing.Sequence[TargetStream]
            List of target stream configurations.

        name : typing.Optional[str]
            The name of the stream.

        description : typing.Optional[str]
            The description of the stream.

        initial_delay : typing.Optional[int]
            The initial delay in seconds before starting the stream creation process.

        timeout_in_mins : typing.Optional[int]
            The maximum duration in minutes for the stream creation process before timing out.

        start_time : typing.Optional[dt.datetime]

        end_time : typing.Optional[dt.datetime]

        timezone : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CreateStreamOut]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/stream",
            method="POST",
            json={
                "name": name,
                "description": description,
                "initial_delay": initial_delay,
                "timeout_in_mins": timeout_in_mins,
                "voices": voices,
                "dictionaries": dictionaries,
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ConfigStream, direction="write"
                ),
                "source_stream": convert_and_respect_annotation_metadata(
                    object_=source_stream, annotation=SourceStream, direction="write"
                ),
                "target_streams": convert_and_respect_annotation_metadata(
                    object_=target_streams, annotation=typing.Sequence[TargetStream], direction="write"
                ),
                "start_time": start_time,
                "end_time": end_time,
                "timezone": timezone,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateStreamOut,
                    parse_obj_as(
                        type_=CreateStreamOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_stream_result(
        self,
        stream_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        stream_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Dict[str, typing.Any]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/stream/{jsonable_encoder(stream_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def stop_stream(
        self,
        stream_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        stream_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Dict[str, typing.Any]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/stream/{jsonable_encoder(stream_id)}/stop",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_probe_stream(
        self,
        *,
        url: str,
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        passphrase: typing.Optional[str] = OMIT,
        stream_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[GetProbeStreamOut]:
        """
        Parameters
        ----------
        url : str

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        passphrase : typing.Optional[str]

        stream_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetProbeStreamOut]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/stream/probe",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "url": url,
                "passphrase": passphrase,
                "stream_id": stream_id,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetProbeStreamOut,
                    parse_obj_as(
                        type_=GetProbeStreamOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

DemixingOption = typing.Union[
    typing.Literal[
        "none", "pick_left_channel", "pick_right_channel", "pick_center_channel", "best_model", "fast_model"
    ],
    typing.Any,
]
